from setuptools import setup, find_packages
from pathlib import Path

# Read README.md with UTF-8 encoding
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='gurulearn',
    version='2.0',
    description='Comprehensive ML library for model analysis, computer vision, medical imaging, and audio processing with enhanced features including confidence metrics and flowbot integration',
    author='Guru Dharsan T',
    author_email='gurudharsan123@gmail.com',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[
        # Core Data Science
        'numpy',
        'pandas',
        'scipy',
        
        # Machine Learning
        'scikit-learn',
        'xgboost',
        
        # Deep Learning
        'tensorflow==2.16.1',
        'keras',
        
        # Image Processing
        'opencv-python',
        'opencv-python-headless',
        'pillow',
        
        # Audio Processing
        'librosa',
        'resampy',
        
        # Visualization
        'matplotlib',
        'seaborn',
        'plotly',
        
        # Utilities
        'tqdm',
        'pathlib',
        'glob3'
    ],
    extras_require={
        'dev': [
            'pytest',
            'black',
            'flake8'
        ]
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Operating System :: OS Independent',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Scientific/Engineering :: Image Processing',
        'Topic :: Scientific/Engineering :: Medical Science Apps.',
    ],
    python_requires='>=3.6',
    keywords='machine learning, deep learning, computer vision, medical imaging, audio processing, AI',
)